nghttp2_session_callbacks_set_rand_callback

Function nghttp2_session_callbacks_set_rand_callback 

pub unsafe extern "C" fn nghttp2_session_callbacks_set_rand_callback(
    cbs: *mut nghttp2_session_callbacks,
    rand_callback: nghttp2_rand_callback,
)
@function

Sets callback function invoked when unpredictable data is needed. Although this callback is optional due to the backward compatibility, it is recommended to specify it to harden the runtime behavior against suspicious activities of a remote endpoint.