nghttp2_session_callbacks_set_send_callback2

Function nghttp2_session_callbacks_set_send_callback2 

pub unsafe extern "C" fn nghttp2_session_callbacks_set_send_callback2(
    cbs: *mut nghttp2_session_callbacks,
    send_callback: nghttp2_send_callback2,
)
@function

Sets callback function invoked when a session wants to send data to the remote peer. This callback is not necessary if the application uses solely nghttp2_session_mem_send2() to serialize data to transmit.